/*
 *	Communication with K-Team robots and devices
 *
 *	Written by Yves Piguet, 1998
 */

#ifndef __KhepCom__
#define __KhepCom__

enum
{
	kKhepNoErr = 0,
	kKhepDeviceErr,
	kKhepComErr,
	kKhepComTimeoutErr,
	kKhepComBadPortErr,
	kKhepComBadBaudRateErr
};

typedef struct
{
	long priv[4];
} KPortRef;	// private data used to maintain the connection state

typedef void *(*reallocPtr)(void *ptr, long size);
	// malloc if ptr == null; return null if failure

#define kNameMaxLength 64
int KGetSerialDeviceName(long i, char *name, long *nameLength);
	// retrieve the name of serial device i (i >= 0)
	// ret. 1 if ok, 0 if none

int KSend(KPortRef *portRef, const char *buf, long length);

int KReceive(KPortRef *portRef, char *buf, long maxLength, long *length);

int KSendCommand(KPortRef *portRef,	// as returned by KOpenSerial
						char *command, long cmdLength,
						char **answer, long answerMaxLength, long *answerLength,
						int stopAtCr,	// if false, read until timeout
						reallocPtr myRealloc);
	// use myRealloc if answerMaxLength is not large enough
	// answer is null-terminated (C-string)

int KOpenSerial(long port, long brate, long timeout, KPortRef *portRef);
	// open and configure the serial port for communicating with Khepera
	// same parameters as SendCommandToKhepera; return a port reference in *portRef
	//  and an error code

void KCloseSerial(KPortRef *portRef);
	// close the serial port

void KFlush(KPortRef *portRef);
	// empty input buffer

int KOpenSendClose(long port, long brate, long timeout,
						char *command, long cmdLength,
						char **answer, long answerMaxLength, long *answerLength,
						int stopAtCr,	// if false, read until timeout
						reallocPtr myRealloc);
	// perform KOpenSerial, KSendCommand, and KCloseSerial

#endif
